#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 enclosed-exceptions
version:              1.0.3
visibility:           public
id:                   enclosed-exceptions-1.0.3-C03wyFlfKXD7wW5m5IDFTa
key:                  enclosed-exceptions-1.0.3-C03wyFlfKXD7wW5m5IDFTa
license:              MIT
maintainer:           jmacristovao@gmail.com, michael@snoyman.com
author:               Michael Snoyman, João Cristóvão
homepage:             https://github.com/jcristovao/enclosed-exceptions
synopsis:             Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>

category:             Control
abi:                  9aa5b4fee5ea117a635acfce224d7ac7
exposed:              True
exposed-modules:      Control.Exception.Enclosed
import-dirs:          /usr/lib/ghc-8.10.5/site-local/enclosed-exceptions-1.0.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/enclosed-exceptions-1.0.3
hs-libraries:         HSenclosed-exceptions-1.0.3-C03wyFlfKXD7wW5m5IDFTa
depends:
    base-4.14.2.0 deepseq-1.4.4.0
    lifted-base-0.2.3.12-HsHHuUVdYcr6iiSvL0hwyv
    monad-control-1.0.2.3-Bi4GOATU8bxGtDgK1rR68J transformers-0.5.6.2
    transformers-base-0.4.5.2-KzHjyAKDkdpHt6juu1Rjxn

haddock-interfaces:
    /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

